@@ -4,6 +4,7 @@
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
+#include "log.h"
 
 #ifdef WITH_DMALLOC
 # include <dmalloc.h>
@@ -22,7 +23,7 @@ int spawn_handler(const int dev_desc_fd, const char * const script)
         execl(script, script, interface, (char *) NULL);
         _exit(EXIT_FAILURE);
     } else if (pid != (pid_t) -1) {
-        printf("Spawning [%s %s]\n", script, interface);
+        logfile(LOG_WARNING, _("Spawning [%s %s]"), script, interface);
 #ifdef HAVE_WAITPID
         (void) waitpid(pid, NULL, 0);
 #else
@@ -34,9 +35,9 @@ int spawn_handler(const int dev_desc_fd, const char * const script)
         }
 #endif
     } else {
-        perror("Unable to spawn the script");
+        logfile(LOG_ERR, _("Unable to spawn the script : %s"),
+                strerror(errno));
         return -1;
     }
     return 0;
 }
-
