@@ -24,6 +24,7 @@
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
+#include <limits.h>
 #include <errno.h>
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -37,6 +38,16 @@
 #endif
 #include <signal.h>
 #include <sys/types.h>
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#elif defined(HAVE_SYS_FCNTL_H)
+# include <sys/fcntl.h>
+#endif
+#ifdef HAVE_IOCTL_H
+# include <ioctl.h>
+#elif defined(HAVE_SYS_IOCTL_H)
+# include <sys/ioctl.h>
+#endif
 #include <sys/socket.h>
 #ifdef HAVE_NETINET_IN_H
 # include <netinet/in.h>
@@ -51,6 +62,10 @@
 #include <poll.h>
 #include <pcap.h>
 
+#include "gettext.h"
+#define  _(txt) gettext(txt)
+#define N_(txt) txt
+
 #include "mysnprintf.h"
 #include "crypto.h"
 #ifndef USE_SYSTEM_CRYPT_SHA1
@@ -75,6 +90,15 @@ extern int errno;
 # define ALLOCA_FREE(X) free(X)
 #endif
 
+#include <syslog.h>
+#ifndef MAX_SYSLOG_LINE
+# define MAX_SYSLOG_LINE 4096U
+#endif
+
+#ifndef __GNUC__
+# define __packed__
+#endif
+
 #define ETHERNET_MTU 1500
 #ifndef IPPROTO_CARP
 # define IPPROTO_CARP 112
@@ -129,15 +153,15 @@ extern int errno;
 #define CAPTURE_TIMEOUT (1000 * 60)
 
 struct carp_softc {
-    int if_flags;			/* current flags to treat UP/DOWN */
+    int if_flags;                       /* current flags to treat UP/DOWN */
     struct ifnet *sc_ifp;
-    struct in_ifaddr *sc_ia;	/* primary iface address */
+    struct in_ifaddr *sc_ia;    /* primary iface address */
 #ifdef INET6
-    struct in6_ifaddr *sc_ia6;	/* primary iface address v6 */
+    struct in6_ifaddr *sc_ia6;  /* primary iface address v6 */
     struct ip6_moptions sc_im6o;
 #endif /* INET6 */
     
-    enum { INIT = 0, BACKUP, MASTER }	sc_state;
+    enum { INIT = 0, BACKUP, MASTER }   sc_state;
 
     int sc_flags_backup;
     int sc_suppress;
@@ -151,25 +175,27 @@ struct carp_softc {
     int sc_advskew;
     int sc_naddrs;
     int sc_naddrs6;
-    int sc_advbase;		/* seconds */
+    int sc_advbase;             /* seconds */
     int sc_init_counter;
     u_int64_t sc_counter;
     
     /* authentication */
-#define CARP_HMAC_PAD	64
+#define CARP_HMAC_PAD   64
     unsigned char sc_key[CARP_KEY_LEN];
     unsigned char sc_pad[CARP_HMAC_PAD];
     SHA1_CTX sc_sha1;
     
-    struct timeval sc_ad_tmo;	/* advertisement timeout */
-    struct timeval sc_md_tmo;	/* master down timeout */
-    struct timeval sc_md6_tmo;	/* master down timeout */
+    struct timeval sc_ad_tmo;   /* advertisement timeout */
+    struct timeval sc_md_tmo;   /* master down timeout */
+    struct timeval sc_md6_tmo;  /* master down timeout */
 };
 
 #define CARP_AUTHLEN 7
 #define DEFAULT_ADVBASE 1U
 #define DEFAULT_DEAD_RATIO 3U
 
+#define DEFAULT_FACILITY LOG_DAEMON
+
 int docarp(void);
 
 #include "globals.h"
